@@ -17,8 +17,8 @@ class Profiles:
 
     def get_env(self):
         try:
-            r = requests.get(self.URI, allow_redirects=True)
-            open(self.ENVIRONMENTS, 'wb').write(r.content)
+            # r = requests.get(self.URI, allow_redirects=True)
+            # open(self.ENVIRONMENTS, 'wb').write(r.content)
             self.env = yaml.load(open(self.ENVIRONMENTS), Loader=yaml.FullLoader)['django']
             self.CONFIG = self.env['cloud']['config']
             print(colored('ARCHIVO DE CONFIGURACIONES -> ' + self.ENVIRONMENTS, 'green'))
@@ -26,4 +26,4 @@ class Profiles:
             raise GenericMicroserviceError(status=500, detail=f'ERROR CONFIG ENV: {e}')
 
     def get_operating_system(self):
-        return self.env['cloud']['config'].get('OPERATING_SYSTEM')
+        return self.file_config.get('operating-system')
